==> office-ui-fabric-vue-7.0.26.tgz: package/lib/utilities/grid/Grid.base.js <==
import '../node_modules/core-js/modules/es.array.concat.js';
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, toMatrix } from '@uifabric-vue/utilities';
import BaseComponent from '../../components/BaseComponent.js';
import '../node_modules/core-js/modules/es.array.map.js';
import '../node_modules/core-js/modules/es.number.constructor.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var GridBase = function (_BaseComponent) {
  _inherits(GridBase, _BaseComponent);

  var _super = _createSuper(GridBase);

  function GridBase() {
    _classCallCheck(this, GridBase);

    return _super.apply(this, arguments);
  }

  _createClass(GridBase, [{
    key: "render",
    value: function render() {
      var _this = this;

      var h = arguments[0];
      var classNames = this.classNames,
          rowsOfItems = this.rowsOfItems;
      return h("table", {
        "class": classNames.root
      }, [h("tbody", [rowsOfItems.map(function (rows, rowIndex) {
        return h("tr", {
          "key": "".concat(_this.uid, "-").concat(rowIndex, "-row"),
          "attrs": {
            "role": "row"
          }
        }, [rows.map(function (cell, cellIndex) {
          return h("td", {
            "key": "".concat(_this.uid, "-").concat(rowIndex, "-").concat(cellIndex, "-cell"),
            "class": classNames.tableCell
          }, [_this.$scopedSlots["default"] ? _this.$scopedSlots["default"]({
            cell: cell,
            index: cellIndex
          }) : null]);
        })]);
      })])]);
    }
  }, {
    key: "rowsOfItems",
    get: function get() {
      var items = this.items,
          columnCount = this.columnCount;
      return toMatrix(items, columnCount);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles;
      return getClassNames(styles, {
        theme: theme
      });
    }
  }]);

  return GridBase;
}(BaseComponent);

__decorate([Prop(), __metadata("design:type", Array)], GridBase.prototype, "items", void 0);

__decorate([Prop(), __metadata("design:type", Number)], GridBase.prototype, "columnCount", void 0);

GridBase = __decorate([Component({
  components: {},
  inheritAttrs: false
})], GridBase);

export { GridBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/utilities/grid/Grid.base.js <==
import 'core-js/modules/es.array.concat';
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction, toMatrix } from '@uifabric-vue/utilities';
import BaseComponent from '../../components/BaseComponent.js';
import 'core-js/modules/es.array.map';
import 'core-js/modules/es.number.constructor';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var GridBase = function (_BaseComponent) {
  _inherits(GridBase, _BaseComponent);

  var _super = _createSuper(GridBase);

  function GridBase() {
    _classCallCheck(this, GridBase);

    return _super.apply(this, arguments);
  }

  _createClass(GridBase, [{
    key: "render",
    value: function render() {
      var _this = this;

      var h = arguments[0];
      var classNames = this.classNames,
          rowsOfItems = this.rowsOfItems;
      return h("table", {
        "class": classNames.root
      }, [h("tbody", [rowsOfItems.map(function (rows, rowIndex) {
        return h("tr", {
          "key": "".concat(_this.uid, "-").concat(rowIndex, "-row"),
          "attrs": {
            "role": "row"
          }
        }, [rows.map(function (cell, cellIndex) {
          return h("td", {
            "key": "".concat(_this.uid, "-").concat(rowIndex, "-").concat(cellIndex, "-cell"),
            "class": classNames.tableCell
          }, [_this.$scopedSlots.default ? _this.$scopedSlots.default({
            cell: cell,
            index: cellIndex
          }) : null]);
        })]);
      })])]);
    }
  }, {
    key: "rowsOfItems",
    get: function get() {
      var items = this.items,
          columnCount = this.columnCount;
      return toMatrix(items, columnCount);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          styles = this.styles;
      return getClassNames(styles, {
        theme: theme
      });
    }
  }]);

  return GridBase;
}(BaseComponent);

__decorate([Prop(), __metadata("design:type", Array)], GridBase.prototype, "items", void 0);

__decorate([Prop(), __metadata("design:type", Number)], GridBase.prototype, "columnCount", void 0);

GridBase = __decorate([Component({
  components: {},
  inheritAttrs: false
})], GridBase);

export { GridBase };
